# -*- coding: utf-8 -*-
import sys, re, json
from bs4 import BeautifulSoup, element
try:
    from urllib2 import urlopen
except ImportError:
    from urllib.request import urlopen
try:
    from urlparse import urlparse, urljoin
except ImportError:
    from urllib.parse import urlparse, urljoin
try:
    from urllib import quote, urlencode
except ImportError:
    from urllib.parse import quote, urlencode


def getsoup(url):
    if (2, 7, 3) <= sys.version_info < (3, 0) or (3, 2) <= sys.version_info < (4, 0):
        return BeautifulSoup(urlopen(url), 'html.parser')
    return BeautifulSoup(urlopen(url), 'html5lib')


def httpget(url):
    return urlopen(url).read().decode('utf-8')


def tv():
    url = 'http://ivi.bupt.edu.cn/'
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'meijunet 500', 'error': str(e)}
    ret = []
    for e in soup.select('div a'):
        if 'href' in e.attrs and e['href'].endswith('.m3u8'):
            title = e.parent.p.text
            ret.append({title: urljoin(url, e['href'])})
    return ret


def category(cat, page=1):
    if page > 1:
        t = 'list%s_%d.html' % (cat, page)
    else:
        t = 'list%s.html' % cat
    url = 'https://www.meijunet.net/vodtypehtml/%s' % t
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'meijunet 100', 'error': str(e)}
    ret = []
    for e in soup.select('ul.stui-vodlist li div.stui-vodlist__box'):
        plot = []
        e1 = e.select('div.stui-vodlist__detail h4 a')[0]
        img = e.select('a.stui-vodlist__thumb')[0]['data-original']
        for e2 in e.select('a.stui-vodlist__thumb span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        plot.append(e.select('div.stui-vodlist__detail p.text')[0].text)
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    e = soup.select('span.num')
    if e:
        e = e[0].text.split('/')
        if int(e[0]) < int(e[1]):
            ret.append({'title': 'Next Page (%d)' % (page + 1), 'category': cat, 'page': page + 1})
    return ret


def search(s, page=1):
    if page > 1:
        t = '%s----------%d---.html' % (quote(s), page)
    else:
        t = '%s-------------.html' % quote(s)
    url = 'https://www.meijunet.net/index.php/vodsearch/%s' % t
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'meijunet 400', 'error': str(e)}
    ret = []
    for e in soup.select('div.stui-pannel-side'):
        e.extract()
    for e in soup.select('ul.stui-vodlist__media li'):
        plot = []
        e1 = e.select('div.detail h3 a')[0]
        img = e.select('div.thumb a.stui-vodlist__thumb')[0]['data-original']
        for e2 in e.select('div.thumb a.stui-vodlist__thumb span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        for e2 in e.select('div.detail span.text-muted'):
            t = e2.text.strip()
            if not t:
                continue
            t = e2.next_sibling
            if isinstance(t, element.NavigableString):
                plot.append(e2.text + e2.next_sibling.strip())
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    e = soup.select('span.num')
    if e:
        e = e[0].text.split('/')
        if int(e[0]) < int(e[1]):
            ret.append({'title': 'Next Page (%d)' % (page + 1), 'search': s, 'page': page + 1})
    return ret


def vod(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'meijunet 200', 'error': str(e)}
    ret = []
    for e in soup.select('div.stui-pannel-box'):
        i = 0
        sites = []
        for e1 in e.select('div.stui-pannel__head ul li a'):
            sites.append(e1.text.strip())
        if sites:
            for e1 in e.select('div.stui-pannel_bd ul.stui-content__playlist'):
                ret1 = []
                for e2 in e1.select('li a'):
                    ret1.append({e2.text: urljoin(url, e2['href'])})
                ret.append({sites[i]: ret1})
                i += 1
            continue
        for e1 in e.select('div.stui-pannel__head h3'):
            sites.append(e1.text.strip())
        if sites:
            ret1 = []
            for e1 in e.select('ul.stui-vodlist__text li'):
                e2 = e1.select('input', {'id': 'checkbox'})
                if not e2:
                    continue
                e2 = e2[0]
                if 'value' not in e2.attrs:
                    continue
                ret1.append({e2.parent.text: e2['value']})
            if ret1:
                ret.append({sites[i]: ret1})
            continue
    return ret


def play(url):
    u = ''
    d = {
        'Iw': ' ', #0x20
        'Ix': '!', #0x21
        'Iy': '"', #0x22
        'Iz': '#', #0x23
        'I0': '$', #0x24
        'I1': '%', #0x25
        'I2': '&', #0x26
        'I3': '\'', #0x27
        'I4': '(', #0x28
        'I5': ')', #0x29
        'JB': '*', #0x2A
        'JC': '+', #0x2B
        'JD': ',', #0x2C
        'JE': '-', #0x2D
        'JF': '.', #0x2E
        'JG': '/', #0x2F
        'Mw': '0', #0x30
        'Mx': '1', #0x31
        'My': '2', #0x32
        'Mz': '3', #0x33
        'M0': '4', #0x34
        'M1': '5', #0x35
        'M2': '6', #0x36
        'M3': '7', #0x37
        'M4': '8', #0x38
        'M5': '9', #0x39
        'NB': ':', #0x3A
        'NC': ';', #0x3B
        'ND': '<', #0x3C
        'NE': '=', #0x3D
        'NF': '>', #0x3E
        'NG': '?', #0x3F
        'Qw': '@', #0x40
        'Qx': 'A', #0x41
        'Qy': 'B', #0x42
        'Qz': 'C', #0x43
        'Q0': 'D', #0x44
        'Q1': 'E', #0x45
        'Q2': 'F', #0x46
        'Q3': 'G', #0x47
        'Q4': 'H', #0x48
        'Q5': 'I', #0x49
        'RB': 'J', #0x4A
        'RC': 'K', #0x4B
        'RD': 'L', #0x4C
        'RE': 'M', #0x4D
        'RF': 'N', #0x4E
        'RG': 'O', #0x4F
        'Uw': 'P', #0x50
        'Ux': 'Q', #0x51
        'Uy': 'R', #0x52
        'Uz': 'S', #0x53
        'U0': 'T', #0x54
        'U1': 'U', #0x55
        'U2': 'V', #0x56
        'U3': 'W', #0x57
        'U4': 'X', #0x58
        'U5': 'Y', #0x59
        'VB': 'Z', #0x5A
        'VC': '[', #0x5B
        'VD': '\\', #0x5C
        'VE': ']', #0x5D
        'VF': '^', #0x5E
        'VG': '_', #0x5F
        'Yw': '`', #0x60
        'Yx': 'a', #0x61
        'Yy': 'b', #0x62
        'Yz': 'c', #0x63
        'Y0': 'd', #0x64
        'Y1': 'e', #0x65
        'Y2': 'f', #0x66
        'Y3': 'g', #0x67
        'Y4': 'h', #0x68
        'Y5': 'i', #0x69
        'ZB': 'j', #0x6A
        'ZC': 'k', #0x6B
        'ZD': 'l', #0x6C
        'ZE': 'm', #0x6D
        'ZF': 'n', #0x6E
        'ZG': 'o', #0x6F
        'cw': 'p', #0x70
        'cx': 'q', #0x71
        'cy': 'r', #0x72
        'cz': 's', #0x73
        'c0': 't', #0x74
        'c1': 'u', #0x75
        'c2': 'v', #0x76
        'c3': 'w', #0x77
        'c4': 'x', #0x78
        'c5': 'y', #0x79
        'dB': 'z', #0x7A
        'dC': '{', #0x7B
        'dD': '|', #0x7C
        'dE': '}', #0x7D
        'dF': '~'} #0x7E
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'meijunet 300', 'error': str(e)}
    s = re.search(r'var player_data=(.*?)</script>', content)
    if not s:
        return {'code': 'meijunet 301'}
    s = s.group(1)
    try:
        data = json.loads(s)
    except Exception as e:
        return {'code': 'meijunet 302', 'error': str(e)}
    for e in data['url'].split('JT'):
        if not e:
            continue
        if e not in d:
            return {'code': 'meijunet 303', 'error': u + '\n' + str(e)}
        u += d[e]
    if u.endswith('.m3u8'):
        return {'title': '', 'url': u}
    return {'code': 'meijunet 304', 'error': u'还没做 而且不打算做了'}
